@@ -32,7 +32,7 @@
  * can't be locked.  Thus, this must always be called in a while loop to stabilize
  * things, since we can always lose the race condition getting to the parent vnode.
  */
-int cm_HaveAccessRights(struct cm_scache *scp, struct cm_user *up, afs_uint32 rights,
+int cm_HaveAccessRights(struct cm_scache *scp, struct cm_user *userp, afs_uint32 rights,
                         afs_uint32 *outRightsp)
 {
     cm_scache_t *aclScp;
@@ -82,7 +82,7 @@ int cm_HaveAccessRights(struct cm_scache *scp, struct cm_user *up, afs_uint32 ri
         *outRightsp = rights;
     } else {
         /* we have to check the specific rights info */
-        code = cm_FindACLCache(aclScp, up, &trights);
+        code = cm_FindACLCache(aclScp, userp, &trights);
         if (code) {
             code = 0;
             goto done;
@@ -107,30 +107,35 @@ int cm_HaveAccessRights(struct cm_scache *scp, struct cm_user *up, afs_uint32 ri
 }
 
 /* called with locked scp; ensures that we have an ACL cache entry for the
- * user specified by the parameter "up."
+ * user specified by the parameter "userp."
  * In pathological race conditions, this function may return success without
  * having loaded the entry properly (due to a racing callback revoke), so this
  * function must also be called in a while loop to make sure that we eventually
  * succeed.
  */
-long cm_GetAccessRights(struct cm_scache *scp, struct cm_user *up,
+long cm_GetAccessRights(struct cm_scache *scp, struct cm_user *userp,
                         struct cm_req *reqp)
 {
     long code;
     cm_fid_t tfid;
     cm_scache_t *aclScp;
+    int got_cb = 0;
 
     /* pretty easy: just force a pass through the fetch status code */
         
-    osi_Log2(afsd_logp, "GetAccess scp %x user %x", scp, up);
+    osi_Log2(afsd_logp, "GetAccess scp %x user %x", scp, userp);
 
     /* first, start by finding out whether we have a directory or something
      * else, so we can find what object's ACL we need.
      */
-    code = cm_SyncOp(scp, NULL, up, reqp, 0, CM_SCACHESYNC_GETSTATUS
-                      | CM_SCACHESYNC_NEEDCALLBACK);
-    if (code) 
-        return code;
+    if (!cm_HaveCallback(scp)) {
+	code = cm_SyncOp(scp, NULL, userp, reqp, 0,
+		      CM_SCACHESYNC_NEEDCALLBACK | CM_SCACHESYNC_GETSTATUS);
+	if (code) 
+	    return code;
+
+	got_cb = 1;
+    }
         
     if (scp->fileType != CM_SCACHETYPE_DIRECTORY) {
         /* not a dir, use parent dir's acl */
@@ -139,20 +144,21 @@ long cm_GetAccessRights(struct cm_scache *scp, struct cm_user *up,
         tfid.vnode = scp->parentVnode;
         tfid.unique = scp->parentUnique;
         lock_ReleaseMutex(&scp->mx);
-        code = cm_GetSCache(&tfid, &aclScp, up, reqp);
+        code = cm_GetSCache(&tfid, &aclScp, userp, reqp);
         if (code) {
             lock_ObtainMutex(&scp->mx);
             return code;
         }       
                 
-        osi_Log1(afsd_logp, "GetAccess parent %x", aclScp);
+        osi_Log2(afsd_logp, "GetAccess parent scp %x user %x", aclScp, userp);
         lock_ObtainMutex(&aclScp->mx);
-        code = cm_GetCallback(aclScp, up, reqp, 1);
+
+	code = cm_GetCallback(aclScp, userp, reqp, 1);
         lock_ReleaseMutex(&aclScp->mx);
         cm_ReleaseSCache(aclScp);
         lock_ObtainMutex(&scp->mx);
-    } else {
-        code = cm_GetCallback(scp, up, reqp, 1);
+    } else if (!got_cb) {
+	code = cm_GetCallback(scp, userp, reqp, 1);
     }
 
     return code;
