@@ -11,10 +11,9 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/volser/volmain.c,v 1.18.2.14 2008/03/10 22:35:37 shadow Exp $");
+    ("$Header: /cvs/openafs/src/volser/volmain.c,v 1.22.2.2 2006/06/20 20:37:12 jaltman Exp $");
 
 #include <sys/types.h>
-#include <string.h>
 #ifdef AFS_NT40_ENV
 #include <time.h>
 #include <fcntl.h>
@@ -25,6 +24,13 @@ RCSID
 #include <sys/file.h>
 #include <netinet/in.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <rx/xdr.h>
 #include <afs/afsint.h>
 #include <stdio.h>
@@ -67,7 +73,6 @@ RCSID
 #define VolserVersion "2.0"
 #define N_SECURITY_OBJECTS 3
 
-extern struct Lock localLock;
 extern struct volser_trans *TransList();
 #ifndef AFS_PTHREAD_ENV
 extern int (*vol_PollProc) ();
@@ -89,8 +94,8 @@ int DoLogging = 0;
 int lwps = 9;
 int udpBufSize = 0;		/* UDP buffer size for receive */
 
+int Testing = 0;		/* for ListViceInodes */
 int rxBind = 0;
-int rxkadDisableDotCheck = 0;
 
 #define ADDRSPERSITE 16         /* Same global is in rx/rx_user.c */
 afs_uint32 SHostAddrs[ADDRSPERSITE];
@@ -143,8 +148,8 @@ TryUnlock()
 }
 
 /* background daemon for timing out transactions */
-static void*
-BKGLoop(void *unused)
+static void
+BKGLoop()
 {
     struct timeval tv;
     int loop = 0;
@@ -165,14 +170,12 @@ BKGLoop(void *unused)
 	    ReOpenLog(AFSDIR_SERVER_VOLSERLOG_FILEPATH);
 	}
     }
-
-    return NULL;
 }
 
 /* Background daemon for sleeping so the volserver does not become I/O bound */
 afs_int32 TTsleep, TTrun;
-static void *
-BKGSleep(void *unused)
+static void
+BKGSleep()
 {
     struct volser_trans *tt;
 
@@ -200,7 +203,6 @@ BKGSleep(void *unused)
 	        VTRANS_UNLOCK;
 	}
     }
-    return NULL;
 }
 
 #ifndef AFS_NT40_ENV
@@ -293,8 +295,6 @@ main(int argc, char **argv)
 	    goto usage;
 	} else if (strcmp(argv[code], "-rxbind") == 0) {
 	    rxBind = 1;
-	} else if (strcmp(argv[code], "-allow-dotted-principals") == 0) {
-	    rxkadDisableDotCheck = 1;
 	} else if (strcmp(argv[code], "-p") == 0) {
 	    lwps = atoi(argv[++code]);
 	    if (lwps > MAXLWP) {
@@ -386,7 +386,7 @@ main(int argc, char **argv)
 #ifndef AFS_NT40_ENV
 	    printf("Usage: volserver [-log] [-p <number of processes>] "
 		   "[-auditlog <log path>] "
-		   "[-nojumbo] [-rxmaxmtu <bytes>] [-rxbind] [-allow-dotted-principals] "
+		   "[-nojumbo] [-rxmaxmtu <bytes>] [-rxbind] "
 		   "[-udpsize <size of socket buffer in bytes>] "
 		   "[-syslog[=FACILITY]] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
@@ -394,7 +394,7 @@ main(int argc, char **argv)
 #else
 	    printf("Usage: volserver [-log] [-p <number of processes>] "
 		   "[-auditlog <log path>] "
-		   "[-nojumbo] [-rxmaxmtu <bytes>] [-rxbind] [-allow-dotted-principals] "
+		   "[-nojumbo] [-rxmaxmtu <bytes>] [-rxbind] "
 		   "[-udpsize <size of socket buffer in bytes>] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
@@ -422,13 +422,7 @@ main(int argc, char **argv)
 	exit(1);
     }
 #endif
-    /* Open VolserLog and map stdout, stderr into it; VInitVolumePackage can
-       log, so we need to do this here */
-    OpenLog(AFSDIR_SERVER_VOLSERLOG_FILEPATH);
-
     VInitVolumePackage(volumeUtility, 0, 0, CONNECT_FS, 0);
-    /* For nuke() */
-    Lock_Init(&localLock);
     DInit(40);
 #ifndef AFS_PTHREAD_ENV
     vol_PollProc = IOMGR_Poll;	/* tell vol pkg to poll io system periodically */
@@ -475,6 +469,8 @@ main(int argc, char **argv)
     rx_SetRxDeadTime(420);
     memset(busyFlags, 0, sizeof(busyFlags));
 
+    /* Open FileLog and map stdout, stderr into it */
+    OpenLog(AFSDIR_SERVER_VOLSERLOG_FILEPATH);
     SetupLogSignals();
 
     {
@@ -518,20 +514,12 @@ main(int argc, char **argv)
     if (lwps < 4)
 	lwps = 4;
     rx_SetMaxProcs(service, lwps);
-#if defined(AFS_XBSD_ENV)
-    rx_SetStackSize(service, (128 * 1024));
-#elif defined(AFS_SGI_ENV)
-    rx_SetStackSize(service, (48 * 1024));
+#ifdef AFS_SGI_ENV
+    rx_SetStackSize(service, 49152);
 #else
-    rx_SetStackSize(service, (32 * 1024));
+    rx_SetStackSize(service, 32768);
 #endif
 
-    if (rxkadDisableDotCheck) {
-        rx_SetSecurityConfiguration(service, RXS_CONFIG_FLAGS,
-                                    (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK,
-                                    NULL);
-    }
-
     service =
 	rx_NewService(0, RX_STATS_SERVICE_ID, "rpcstats", securityObjects, 3,
 		      RXSTATS_ExecuteRequest);
@@ -554,5 +542,4 @@ main(int argc, char **argv)
 
     osi_audit(VS_FinishEvent, (-1), AUD_END);
     Abort("StartServer returned?");
-    return 0; /* not reached */
 }
